landsat-util
============

.. image:: https://travis-ci.org/developmentseed/landsat-util.svg?branch=v0.5
    :target: https://travis-ci.org/developmentseed/landsat-util

.. image:: https://badge.fury.io/py/landsat-util.svg
    :target: http://badge.fury.io/py/landsat-util

.. image:: https://img.shields.io/pypi/dm/landsat-util.svg
    :target: https://pypi.python.org/pypi/landsat-util/
    :alt: Downloads

.. image:: https://img.shields.io/pypi/l/landsat-util.svg
    :target: https://pypi.python.org/pypi/landsat-util/
    :alt: License

Landsat-util is a command line utility that makes it easy to search, download, and process Landsat imagery.

This tool uses Development Seed's `API for Landsat Metadata <https://github.com/developmentseed/landsat-api>`_.

This API is accessible here: https://api.developmentseed.org/landsat

You can also run your own API and connect it to this tool.

**Table of Contents:**

.. toctree::
   :maxdepth: 3

   installation
   overview
   commands
   todo
   api
   notes



